==================
Installation Guide
==================

.. meta::
   :description: Installation of pyTelegramBotAPI
   :keywords: ptba, pytba, pyTelegramBotAPI, installation, guide


Using PIP
----------
.. code-block:: bash

    $ pip install pyTelegramBotAPI

Using pipenv
------------
.. code-block:: bash

    $ pipenv install pyTelegramBotAPI

By cloning repository
---------------------
.. code-block:: bash

    $ git clone https://github.com/eternnoir/pyTelegramBotAPI.git
    $ cd pyTelegramBotAPI
    $ python setup.py install

Directly using pip
------------------
.. code-block:: bash

    $ pip install git+https://github.com/eternnoir/pyTelegramBotAPI.git


It is generally recommended to use the first option.

While the API is production-ready, it is still under development and it has regular updates, do not forget to update it regularly by calling:

.. code-block:: bash

    $ pip install pytelegrambotapi --upgrade


